import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

//years 
const numberFormat = number =>
  	(Math.abs(Number(number)))  ;


const render = data => {
  const pieData = pie().sort(null).value(d=>d.population)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(100)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.population))
  	.on("mouseover", d => console.log(d.data.population));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.year));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.year);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.population));
}

// url of my data giest

const csvUrl =
 'https://gist.githubusercontent.com/snehareddygurram/1fe8376c5a6b27ac0e192245d8d94c22/raw/00c22ac0721c5d160892c53a87fd18875f7ceb31/Population.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.population-data1.population);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});